#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#define F_CPU 16000000

int start = 0;

ISR(PCINT3_vect)
{
    if(start == 0 && (PIND & (1 << PD6)) == 0)
    {
        start = 1;
    }
}

void PCINT_init()
{
    PCICR |= (1 << PCIE3);
    PCMSK3 |= (1 << PCINT30);
}

void init_timer() {
	DDRD |= (1 << PD4) | (1 << PD5);

	TCCR1A |= (1 << WGM11) | (1 << COM1B1) | (1 << COM1A1);
	TCCR1B |= (1 << WGM12) | (1 << WGM13) | (1 << CS12);
	
	ICR1 = 100;
}
 
void init_sensor()
{
    // setez pinii ca input
    DDRB = 0;

    // setez rezistentele de pull-up
    PORTB |= (1 << PB0);
    PORTB |= (1 << PB1);
    PORTB |= (1 << PB2);
    PORTB |= (1 << PB3);
    PORTB |= (1 << PB4);
    PORTB |= (1 << PB5);
    PORTB |= (1 << PB6);
    PORTB |= (1 << PB7);
}

int main(void)
{
	int i;
	int sensors[8];
	
	DDRD &= ~(1 << PD6);    // pinul PD6 va fi input (buton)
	PORTD |= (1 << PD6);    // activam rezistenta de pull-up
    DDRD |= (1 << PD7);     // pinul PD7 va fi output (LED)
    PORTD &= ~(1 << PD7);   // initial LED-ul va fi oprit
	
	// pini enable setati ca output
    DDRD |= (1 << PD0) | (1 << PD1) | (1 << PD2) | (1 << PD3);
    PORTD &= ~(1 << PD0);
    PORTD &= ~(1 << PD1);
    PORTD &= ~(1 << PD2);
    PORTD &= ~(1 << PD3);

	
	// initializare timer
	init_timer();
    init_sensor();
    // interrupt init
    PCINT_init();
    sei();
	
    while(start == 0)
    {
        PORTD ^= (1<<PD7);
        _delay_ms(100);
    }
    PORTD &= ~(1<<PD7);
    _delay_ms(1000);
    PORTD |= (1<<PD7);

    OCR1B = 0.5 * ICR1;
    OCR1A = 0.5 * ICR1;
    PORTD |= (1 << PD0);
    PORTD &= ~(1 << PD1);
    PORTD |= (1 << PD2);
    PORTD &= ~(1 << PD3);
	while (1)
	{
        int eq = 1;
        sensors[0] = (PINB & (1 << PB0));
        sensors[1] = (PINB & (1 << PB1));
        sensors[2] = (PINB & (1 << PB2));
        sensors[3] = (PINB & (1 << PB3));
        sensors[4] = (PINB & (1 << PB4));
        sensors[5] = (PINB & (1 << PB5));
        sensors[6] = (PINB & (1 << PB6));
        sensors[7] = (PINB & (1 << PB7));
        /*
        for(i = 0; i < 8; i++)
        {
            if(i > 0 && eq == 1)
            {
                if(sensors[i] != sensors[i-1])
                {
                    eq = 0;
                }
            }
        }
        if(eq == 1)
        {
            OCR1B = 0;
            OCR1A = 0;
            continue;
        }
        */
		if(sensors[4] != 0 || sensors[3] != 0)
        {
			OCR1B = 0.5 * ICR1;
			OCR1A = 0.5 * ICR1;
		}
        else if(sensors[0] != 0 || sensors[1] != 0 || sensors[2] != 0)
        {
			OCR1B = 0.5 * ICR1;
			OCR1A = 0.2 * ICR1;
		}
		else if(sensors[5] != 0 || sensors[6] != 0 || sensors[7] != 0)
        {
			OCR1B = 0.2 * ICR1;
			OCR1A = 0.5 * ICR1;
		}
    }
	return 0;
}
